@@ -952,6 +952,7 @@ impl<'a> Emitter<'a> {
             ClassMember::PrivateProp(ref n) => emit!(n),
             ClassMember::TsIndexSignature(ref n) => emit!(n),
             ClassMember::Empty(ref n) => emit!(n),
+            ClassMember::StaticBlock(ref n) => emit!(n),
         }
     }
 
@@ -1216,6 +1217,21 @@ impl<'a> Emitter<'a> {
         }
     }
 
+    #[emitter]
+    fn emit_static_block(&mut self, n: &StaticBlock) -> Result {
+        self.emit_leading_comments_of_span(n.span(), false)?;
+        keyword!("static");
+        formatting_space!();
+        punct!("{");
+        self.emit_list(
+            n.span(),
+            Some(&n.body),
+            ListFormat::MultiLineBlockStatements,
+        )?;
+        self.emit_leading_comments_of_span(n.span(), true)?;
+        punct!("}");
+    }
+
     #[emitter]
     fn emit_prop_name(&mut self, node: &PropName) -> Result {
         match *node {
